==> kubernetes-model-1.0.54-sources.jar: annotations/io/fabric8/kubernetes/api/model/NamespaceSpecBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class NamespaceSpecBuilder extends NamespaceSpecFluentImpl<NamespaceSpecBuilder> implements VisitableBuilder<NamespaceSpec,NamespaceSpecBuilder>{

    NamespaceSpecFluent<?> fluent;
    Boolean validationEnabled;

    public NamespaceSpecBuilder(){
            this(true);
    }
    public NamespaceSpecBuilder(Boolean validationEnabled){
            this(new NamespaceSpec(), validationEnabled);
    }
    public NamespaceSpecBuilder(NamespaceSpecFluent<?> fluent){
            this(fluent, true);
    }
    public NamespaceSpecBuilder(NamespaceSpecFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new NamespaceSpec(), validationEnabled);
    }
    public NamespaceSpecBuilder(NamespaceSpecFluent<?> fluent,NamespaceSpec instance){
            this(fluent, instance, true);
    }
    public NamespaceSpecBuilder(NamespaceSpecFluent<?> fluent,NamespaceSpec instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withFinalizers(instance.getFinalizers()); 
            this.validationEnabled = validationEnabled; 
    }
    public NamespaceSpecBuilder(NamespaceSpec instance){
            this(instance,true);
    }
    public NamespaceSpecBuilder(NamespaceSpec instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withFinalizers(instance.getFinalizers()); 
            this.validationEnabled = validationEnabled; 
    }

    public NamespaceSpec build(){
            NamespaceSpec buildable = new NamespaceSpec(fluent.getFinalizers());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            NamespaceSpecBuilder that = (NamespaceSpecBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.60-sources.jar: annotations/io/fabric8/kubernetes/api/model/NamespaceSpecBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class NamespaceSpecBuilder extends NamespaceSpecFluentImpl<NamespaceSpecBuilder> implements VisitableBuilder<NamespaceSpec,NamespaceSpecBuilder>{

    NamespaceSpecFluent<?> fluent;
    Boolean validationEnabled;

    public NamespaceSpecBuilder(){
            this(true);
    }
    public NamespaceSpecBuilder(Boolean validationEnabled){
            this(new NamespaceSpec(), validationEnabled);
    }
    public NamespaceSpecBuilder(NamespaceSpecFluent<?> fluent){
            this(fluent, true);
    }
    public NamespaceSpecBuilder(NamespaceSpecFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new NamespaceSpec(), validationEnabled);
    }
    public NamespaceSpecBuilder(NamespaceSpecFluent<?> fluent,NamespaceSpec instance){
            this(fluent, instance, true);
    }
    public NamespaceSpecBuilder(NamespaceSpecFluent<?> fluent,NamespaceSpec instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withFinalizers(instance.getFinalizers()); 
            this.validationEnabled = validationEnabled; 
    }
    public NamespaceSpecBuilder(NamespaceSpec instance){
            this(instance,true);
    }
    public NamespaceSpecBuilder(NamespaceSpec instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withFinalizers(instance.getFinalizers()); 
            this.validationEnabled = validationEnabled; 
    }

    public NamespaceSpec build(){
            NamespaceSpec buildable = new NamespaceSpec(fluent.getFinalizers());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            NamespaceSpecBuilder that = (NamespaceSpecBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
